---
title: Основные каталоги Debian Linux
slug: администрирование/основные-каталоги-debian-linux
---

> Эта структура почти одинакова для всех дистрибутивов Linux. Эти каталоги используются для чёткого разделения ролей файлов и упрощения администрирования серверов.

---

# 📁 Подробное описание всех каталогов

## `/`
Корневая директория всей файловой системы.
- Все каталоги и файлы находятся внутри `/`.
- Удаление или повреждение `/` критично для всей системы.

## `/bin`
Базовые системные утилиты.
- Программы, необходимые для работы системы даже в аварийном режиме: `ls`, `cp`, `mv`, `rm`, `cat`.

## `/boot`
Файлы загрузки системы.
- Ядро Linux (`vmlinuz`), начальный RAM-диск (`initrd.img`), конфигурация загрузчика GRUB (`/boot/grub/`).

## `/dev`
Файлы устройств.
- Представляют устройства как файлы: диски, терминалы, USB-устройства.
- Управляются системой через `udev`.

## `/etc`
Конфигурационные файлы системы и программ.
- Все настройки сервисов: `nginx`, `ssh`, `cron`, `network`, `fstab`.
- Ключевая директория для резервного копирования.

## `/home`
Домашние каталоги пользователей.
- Личные файлы и настройки.
- Часто сохраняется отдельно при переустановке системы.

## `/lib`
Системные библиотеки.
- Файлы `.so`, которые используют программы из `/bin` и `/sbin`.

## `/media`
Точки автоматического монтирования внешних носителей.
- USB-флешки, внешние диски, CD/DVD.

## `/mnt`
Временная точка монтирования.
- Используется для ручного монтирования дополнительных файловых систем.

## `/opt`
Каталог для сторонних приложений.
- ПО, установленное вручную, минуя систему пакетов (`apt`).

## `/proc`
Виртуальная файловая система с данными о процессах.
- Отображает состояние ядра и процессов в реальном времени.

## `/root`
Домашний каталог суперпользователя `root`.
- Используется для хранения личных данных администратора.

## `/run`
Данные текущего сеанса работы системы.
- PID-файлы, сокеты и другая временная информация.

## `/sbin`
Системные утилиты для управления.
- Программы для настройки сети, управления дисками, восстановления системы.

## `/srv`
Данные для сервисов.
- Например, веб-сайты, базы данных FTP/HTTP-серверов.

## `/sys`
Виртуальная файловая система для управления устройствами и драйверами.
- Позволяет взаимодействовать с ядром.

## `/tmp`
Каталог для временных файлов.
- Часто очищается при перезагрузке.

## `/usr`
Пользовательские приложения и библиотеки.
- `/usr/bin/` — программы.
- `/usr/lib/` — библиотеки.
- `/usr/share/` — статические ресурсы (документация, локализация).

## `/var`
Динамические данные системы.
- Логи (`/var/log/`), кэш (`/var/cache/`), базы данных и очереди почты.

---

# 📁 Каталоги и их краткое назначение

| Каталог | Описание |
|:---|:---|
| `/` | Корень всей файловой системы. |
| `/bin` | Базовые утилиты: `ls`, `cp`, `mv`, `rm`, `cat`. |
| `/boot` | Файлы загрузки: ядро, initrd.img, grub. |
| `/dev` | Устройства в виде файлов: диски, USB, терминалы. |
| `/etc` | Конфигурации системы и сервисов. |
| `/home` | Домашние каталоги пользователей. |
| `/lib` | Библиотеки для приложений и утилит. |
| `/media` | Точки монтирования USB и CD. |
| `/mnt` | Временное ручное монтирование. |
| `/opt` | Сторонние программы (не через apt). |
| `/proc` | Виртуальные файлы процессов и ядра. |
| `/root` | Личный каталог root-пользователя. |
| `/run` | Текущие сессионные данные системы. |
| `/sbin` | Системные утилиты (монтирование, сеть). |
| `/srv` | Данные сервисов: сайты, базы. |
| `/sys` | Доступ к устройствам и модулям ядра. |
| `/tmp` | Временные файлы приложений. |
| `/usr` | Приложения, библиотеки, статические ресурсы. |
| `/var` | Логи, кэши, базы данных, очереди. |

---

# 📋 Важные каталоги для бэкапа

- `/etc/` — все настройки серверов.
- `/var/` — базы, логи, кэши.
- `/home/` — личные данные пользователей.
- `/opt/` — сторонние приложения.
- `/root/` — файлы администратора.

---

